Crate loadsmith_core

Crate loadsmith_core 

Core types, traits, and errors for the loadsmith mod-manager library.

This is an internal crate of the [loadsmith] workspace. Most consumers should depend on the loadsmith facade crate instead of using this crate directly.

Structs

Dependency
InstalledFile
InstalledPackage
PackageId
PackageRef
Version
SemVer version as defined by https://semver.org.
VersionReq
SemVer version requirement describing the intersection of some version comparators, such as >=1.2.3, <1.8.

Enums

Checksum
ChecksumAlgorithm
Error
FileUrl

Type Aliases

Result